@@ -8,24 +8,24 @@ from mnapy import Wire
 
 class ANDGate:
     def __init__(
-            self,
-            context,
-            options,
-            tag,
-            units,
-            High_Voltage,
-            V_1,
-            V_1_prime,
-            V_in1,
-            V_partial1,
-            V_2,
-            V_2_prime,
-            V_in2,
-            V_partial2,
-            V_out,
-            V_eq,
-            options_units,
-            option_limits,
+        self,
+        context,
+        options,
+        tag,
+        units,
+        High_Voltage,
+        V_1,
+        V_1_prime,
+        V_in1,
+        V_partial1,
+        V_2,
+        V_2_prime,
+        V_in2,
+        V_partial2,
+        V_out,
+        V_eq,
+        options_units,
+        option_limits,
     ):
         self.options = options
         self.tag = tag
@@ -56,12 +56,12 @@ class ANDGate:
 
     def Set_High_Voltage(self, setter: float) -> None:
         if (
-                abs(setter) >= abs(self.option_limits.High_Voltage[0])
-                and abs(setter) <= abs(self.option_limits.High_Voltage[1])
+            abs(setter) >= abs(self.option_limits.High_Voltage[0])
+            and abs(setter) <= abs(self.option_limits.High_Voltage[1])
         ) or abs(setter) == 0:
             self.High_Voltage = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_High_Voltage(self) -> float:
         return self.High_Voltage
@@ -73,13 +73,15 @@ class ANDGate:
         sum = 0
         N = 2
         size = len(ui)
-        
+
         for i in range(0, len(ui)):
             sum += size / (1 + ui[i] + self.context.Params.SystemConstants.ZERO_BIAS)
 
         return N / sum + self.context.Params.SystemConstants.ZERO_BIAS
 
-    def partial_and(self, terminal: float, ui: List[float], ui_prime: List[float]) -> float:
+    def partial_and(
+        self, terminal: float, ui: List[float], ui_prime: List[float]
+    ) -> float:
         sum = 0
         N = 2
         size = len(ui)
@@ -87,10 +89,15 @@ class ANDGate:
         for i in range(0, len(ui)):
             sum += size / (1 + ui[i] + self.context.Params.SystemConstants.ZERO_BIAS)
 
-        return (2 * N * ui_prime[terminal]) / math.pow((1 + ui[terminal] + self.context.Params.SystemConstants.ZERO_BIAS) * sum, 2)
+        return (2 * N * ui_prime[terminal]) / math.pow(
+            (1 + ui[terminal] + self.context.Params.SystemConstants.ZERO_BIAS) * sum, 2
+        )
 
     def update(self):
-        if self.context.Params.SystemFlags.FlagSimulating and self.context.solutions_ready:
+        if (
+            self.context.Params.SystemFlags.FlagSimulating
+            and self.context.solutions_ready
+        ):
             self.V_in1 = self.context.get_voltage(self.Nodes[0], -1)
             self.V_1 = math.tanh(10 * (self.V_in1 / self.High_Voltage - 0.5))
             self.V_1_prime = 10 * (1.0 - self.V_1 * self.V_1)
@@ -99,19 +106,33 @@ class ANDGate:
             self.V_2_prime = 10 * (1.0 - self.V_2 * self.V_2)
             self.V_out = self.vout_and([self.V_1, self.V_2])
             self.V_partial1 = Utils.Utils.limit(
-                self.partial_and(0, [self.V_1, self.V_2], [self.V_1_prime, self.V_2_prime]),
+                self.partial_and(
+                    0, [self.V_1, self.V_2], [self.V_1_prime, self.V_2_prime]
+                ),
                 0.0,
-                1.0
+                1.0,
             )
             self.V_partial2 = Utils.Utils.limit(
-                self.partial_and(1, [self.V_1, self.V_2], [self.V_1_prime, self.V_2_prime]),
+                self.partial_and(
+                    1, [self.V_1, self.V_2], [self.V_1_prime, self.V_2_prime]
+                ),
                 0.0,
-                1.0
+                1.0,
+            )
+            self.V_eq = self.High_Voltage * (
+                self.V_partial1 * (self.V_in1 / self.High_Voltage)
+                + self.V_partial2 * (self.V_in2 / self.High_Voltage)
+                - self.V_out
             )
-            self.V_eq = self.High_Voltage * (self.V_partial1 * (self.V_in1 / self.High_Voltage) + self.V_partial2 * (self.V_in2 / self.High_Voltage) - self.V_out)
 
     def stamp(self):
-        self.context.stamp_gate2(self.Nodes[2], self.V_partial1, self.V_partial2, self.V_eq, self.context.ELEMENT_AND_OFFSET + self.SimulationId)
+        self.context.stamp_gate2(
+            self.Nodes[2],
+            self.V_partial1,
+            self.V_partial2,
+            self.V_eq,
+            self.context.ELEMENT_AND_OFFSET + self.SimulationId,
+        )
 
     def SetId(self, Id: str) -> None:
         self.Id = int(Id)
