@@ -8,22 +8,22 @@ from mnapy import Wire
 
 class LightEmittingDiode:
     def __init__(
-            self,
-            context,
-            Turn_On_Current,
-            Last_Voltage,
-            Last_Current,
-            Saturation_Current,
-            Emission_Coefficient,
-            units,
-            options_units,
-            Wavelength,
-            option_limits,
-            Resistance,
-            Voltage,
-            options,
-            tag,
-            Equivalent_Current,
+        self,
+        context,
+        Turn_On_Current,
+        Last_Voltage,
+        Last_Current,
+        Saturation_Current,
+        Emission_Coefficient,
+        units,
+        options_units,
+        Wavelength,
+        option_limits,
+        Resistance,
+        Voltage,
+        options,
+        tag,
+        Equivalent_Current,
     ):
         self.Turn_On_Current = Turn_On_Current
         self.Last_Voltage = Last_Voltage
@@ -59,12 +59,12 @@ class LightEmittingDiode:
     def Set_Saturation_Current(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Saturation_Current[0])
-                and abs(setter) <= abs(self.option_limits.Saturation_Current[1])
+            abs(setter) >= abs(self.option_limits.Saturation_Current[0])
+            and abs(setter) <= abs(self.option_limits.Saturation_Current[1])
         ) or abs(setter) == 0:
             self.Saturation_Current = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Saturation_Current(self) -> float:
         None
@@ -73,12 +73,12 @@ class LightEmittingDiode:
     def Set_Emission_Coefficient(self, setter: float) -> None:
         None
         if (
-                setter > self.option_limits.Emission_Coefficient[0]
-                and setter < self.option_limits.Emission_Coefficient[1]
+            setter > self.option_limits.Emission_Coefficient[0]
+            and setter < self.option_limits.Emission_Coefficient[1]
         ):
             self.Emission_Coefficient = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Emission_Coefficient(self) -> float:
         None
@@ -87,12 +87,12 @@ class LightEmittingDiode:
     def Set_Wavelength(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Wavelength[0])
-                and abs(setter) <= abs(self.option_limits.Wavelength[1])
+            abs(setter) >= abs(self.option_limits.Wavelength[0])
+            and abs(setter) <= abs(self.option_limits.Wavelength[1])
         ) or abs(setter) == 0:
             self.Wavelength = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Wavelength(self) -> float:
         None
@@ -112,7 +112,10 @@ class LightEmittingDiode:
 
     def update(self) -> None:
         None
-        if self.context.Params.SystemFlags.FlagSimulating and self.context.solutions_ready:
+        if (
+            self.context.Params.SystemFlags.FlagSimulating
+            and self.context.solutions_ready
+        ):
             self.Last_Voltage = self.Voltage
             self.Last_Current = self.Equivalent_Current
             next_voltage: float = self.context.get_voltage(self.Nodes[0], self.Nodes[1])
@@ -133,45 +136,49 @@ class LightEmittingDiode:
 
             diode_voltage = Utils.Utils.limit(diode_voltage, -vcrit, vcrit)
             self.gmin = Utils.Utils.gmin_step(
-                self.gmin_start, self.get_led_error(), self.context.iterator, self.context
+                self.gmin_start,
+                self.get_led_error(),
+                self.context.iterator,
+                self.context,
             )
             self.Voltage = diode_voltage
             self.Resistance = 1.0 / (
-                    (
-                            self.Saturation_Current
-                            / (
-                                    self.Emission_Coefficient
-                                    * self.context.Params.SystemSettings.THERMAL_VOLTAGE
-                            )
-                    )
-                    * math.exp(
-                self.Voltage
-                / (
+                (
+                    self.Saturation_Current
+                    / (
                         self.Emission_Coefficient
                         * self.context.Params.SystemSettings.THERMAL_VOLTAGE
+                    )
+                )
+                * math.exp(
+                    self.Voltage
+                    / (
+                        self.Emission_Coefficient
+                        * self.context.Params.SystemSettings.THERMAL_VOLTAGE
+                    )
                 )
             )
-            )
             self.Equivalent_Current = -(
-                    self.Saturation_Current
-                    * (
-                            math.exp(
-                                self.Voltage
-                                / (
-                                        self.Emission_Coefficient
-                                        * self.context.Params.SystemSettings.THERMAL_VOLTAGE
-                                )
-                            )
-                            - 1
+                self.Saturation_Current
+                * (
+                    math.exp(
+                        self.Voltage
+                        / (
+                            self.Emission_Coefficient
+                            * self.context.Params.SystemSettings.THERMAL_VOLTAGE
+                        )
                     )
-                    - self.Voltage / self.Resistance
+                    - 1
+                )
+                - self.Voltage / self.Resistance
             )
         else:
             None
 
     def stamp(self) -> None:
         None
-        self.context.stamp_resistor(self.Nodes[0], self.Nodes[1], 1.0 / self.gmin)
+        if self.context.iterator >= self.gmin_start:
+            self.context.stamp_resistor(self.Nodes[0], self.Nodes[1], 1.0 / self.gmin)
         self.context.stamp_current(
             self.Nodes[0], self.Nodes[1], self.Equivalent_Current
         )
@@ -221,9 +228,9 @@ class LightEmittingDiode:
     def turn_on_check(self) -> None:
         None
         if (
-                abs(self.Equivalent_Current) > self.Turn_On_Current
-                and self.Last_Current > self.Turn_On_Current
-                and self.context.simulation_step != 0
+            abs(self.Equivalent_Current) > self.Turn_On_Current
+            and self.Last_Current > self.Turn_On_Current
+            and self.context.simulation_step != 0
         ):
             self.led_status = self.context.Params.SystemConstants.ON
         else:
