@@ -7,27 +7,27 @@ from mnapy import Wire
 
 class VoltageControlledCapacitor:
     def __init__(
-            self,
-            context,
-            Transient_Resistance,
-            Initial_Voltage,
-            Output_Capacitance,
-            Elm1,
-            Input_Voltage,
-            Elm0,
-            units,
-            High_Voltage,
-            Elm3,
-            Transient_Current,
-            Elm2,
-            options_units,
-            Low_Voltage,
-            option_limits,
-            Interpolate,
-            options,
-            tag,
-            Transient_Voltage,
-            Equivalent_Current,
+        self,
+        context,
+        Transient_Resistance,
+        Initial_Voltage,
+        Output_Capacitance,
+        Elm1,
+        Input_Voltage,
+        Elm0,
+        units,
+        High_Voltage,
+        Elm3,
+        Transient_Current,
+        Elm2,
+        options_units,
+        Low_Voltage,
+        option_limits,
+        Interpolate,
+        options,
+        tag,
+        Transient_Voltage,
+        Equivalent_Current,
     ):
         self.Transient_Resistance = Transient_Resistance
         self.Initial_Voltage = Initial_Voltage
@@ -64,11 +64,11 @@ class VoltageControlledCapacitor:
     def Set_Interpolate(self, setter: str) -> None:
         None
         if setter == (self.context.Params.SystemConstants.ON) or setter == (
-                self.context.Params.SystemConstants.OFF
+            self.context.Params.SystemConstants.OFF
         ):
             self.Interpolate = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Interpolate(self) -> str:
         None
@@ -77,12 +77,12 @@ class VoltageControlledCapacitor:
     def Set_Initial_Voltage(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Initial_Voltage[0])
-                and abs(setter) <= abs(self.option_limits.Initial_Voltage[1])
+            abs(setter) >= abs(self.option_limits.Initial_Voltage[0])
+            and abs(setter) <= abs(self.option_limits.Initial_Voltage[1])
         ) or abs(setter) == 0:
             self.Initial_Voltage = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Initial_Voltage(self) -> float:
         None
@@ -91,12 +91,12 @@ class VoltageControlledCapacitor:
     def Set_Elm1(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Elm1[0])
-                and abs(setter) <= abs(self.option_limits.Elm1[1])
+            abs(setter) >= abs(self.option_limits.Elm1[0])
+            and abs(setter) <= abs(self.option_limits.Elm1[1])
         ) or abs(setter) == 0:
             self.Elm1 = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Elm1(self) -> float:
         None
@@ -105,12 +105,12 @@ class VoltageControlledCapacitor:
     def Set_Elm0(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Elm0[0])
-                and abs(setter) <= abs(self.option_limits.Elm0[1])
+            abs(setter) >= abs(self.option_limits.Elm0[0])
+            and abs(setter) <= abs(self.option_limits.Elm0[1])
         ) or abs(setter) == 0:
             self.Elm0 = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Elm0(self) -> float:
         None
@@ -119,12 +119,12 @@ class VoltageControlledCapacitor:
     def Set_Elm3(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Elm3[0])
-                and abs(setter) <= abs(self.option_limits.Elm3[1])
+            abs(setter) >= abs(self.option_limits.Elm3[0])
+            and abs(setter) <= abs(self.option_limits.Elm3[1])
         ) or abs(setter) == 0:
             self.Elm3 = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Elm3(self) -> float:
         None
@@ -133,12 +133,12 @@ class VoltageControlledCapacitor:
     def Set_Elm2(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Elm2[0])
-                and abs(setter) <= abs(self.option_limits.Elm2[1])
+            abs(setter) >= abs(self.option_limits.Elm2[0])
+            and abs(setter) <= abs(self.option_limits.Elm2[1])
         ) or abs(setter) == 0:
             self.Elm2 = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Elm2(self) -> float:
         None
@@ -146,34 +146,40 @@ class VoltageControlledCapacitor:
 
     def reset(self) -> None:
         None
-        if (self.context.integration_method == "trapezoidal"):
-            self.Transient_Resistance = self.context.time_step / (2 * self.Output_Capacitance)
+        if self.context.integration_method == "trapezoidal":
+            self.Transient_Resistance = self.context.time_step / (
+                2 * self.Output_Capacitance
+            )
             self.Transient_Voltage = self.Initial_Voltage
             self.Transient_Current = 0
             self.Equivalent_Current = (
-                    -self.Transient_Voltage / self.Transient_Resistance - self.Transient_Current
+                -self.Transient_Voltage / self.Transient_Resistance
+                - self.Transient_Current
             )
-        elif (self.context.integration_method == "backward_euler"):
+        elif self.context.integration_method == "backward_euler":
             self.Transient_Resistance = self.context.time_step / self.Output_Capacitance
             self.Transient_Voltage = self.Initial_Voltage
             self.Transient_Current = 0
             self.Equivalent_Current = (
-                    -self.Transient_Voltage / self.Transient_Resistance
+                -self.Transient_Voltage / self.Transient_Resistance
             )
         else:
-            self.Transient_Resistance = self.context.time_step / (2 * self.Output_Capacitance)
+            self.Transient_Resistance = self.context.time_step / (
+                2 * self.Output_Capacitance
+            )
             self.Transient_Voltage = self.Initial_Voltage
             self.Transient_Current = 0
             self.Equivalent_Current = (
-                    -self.Transient_Voltage / self.Transient_Resistance - self.Transient_Current
+                -self.Transient_Voltage / self.Transient_Resistance
+                - self.Transient_Current
             )
 
     def update(self) -> None:
         None
         if (
-                self.context.Params.SystemFlags.FlagSimulating
-                and self.context.solutions_ready
-                and self.context.simulation_step != 0
+            self.context.Params.SystemFlags.FlagSimulating
+            and self.context.solutions_ready
+            and self.context.simulation_step != 0
         ):
             self.Input_Voltage = Utils.Utils.limit(
                 self.context.get_voltage(self.Nodes[1], -1),
@@ -194,29 +200,29 @@ class VoltageControlledCapacitor:
             elif self.Interpolate == (self.context.Params.SystemConstants.OFF):
                 index: int = 0
                 if (
-                        self.Input_Voltage >= self.High_Voltage * 0
-                        and self.Input_Voltage <= self.High_Voltage * 0.25
+                    self.Input_Voltage >= self.High_Voltage * 0
+                    and self.Input_Voltage <= self.High_Voltage * 0.25
                 ):
                     index = 0
                 elif (
-                        self.Input_Voltage >= self.High_Voltage * 0.25
-                        and self.Input_Voltage <= self.High_Voltage * 0.5
+                    self.Input_Voltage >= self.High_Voltage * 0.25
+                    and self.Input_Voltage <= self.High_Voltage * 0.5
                 ):
                     index = 1
                 elif (
-                        self.Input_Voltage >= self.High_Voltage * 0.5
-                        and self.Input_Voltage <= self.High_Voltage * 0.75
+                    self.Input_Voltage >= self.High_Voltage * 0.5
+                    and self.Input_Voltage <= self.High_Voltage * 0.75
                 ):
                     index = 2
                 elif (
-                        self.Input_Voltage >= self.High_Voltage * 0.75
-                        and self.Input_Voltage <= self.High_Voltage * 1.0
+                    self.Input_Voltage >= self.High_Voltage * 0.75
+                    and self.Input_Voltage <= self.High_Voltage * 1.0
                 ):
                     index = 3
 
-                self.Output_Capacitance = [
-                    self.Elm0, self.Elm1, self.Elm2, self.Elm3
-                ][index]
+                self.Output_Capacitance = [self.Elm0, self.Elm1, self.Elm2, self.Elm3][
+                    index
+                ]
 
     def stamp(self) -> None:
         None
@@ -226,7 +232,6 @@ class VoltageControlledCapacitor:
             self.Transient_Resistance,
             self.Equivalent_Current,
         )
-        self.context.stamp_node(self.Nodes[1], self.context.Params.SystemSettings.R_MAX)
 
     def SetId(self, Id: str) -> None:
         None
@@ -271,31 +276,63 @@ class VoltageControlledCapacitor:
             self.conserve_energy()
             voltage: float = self.context.get_voltage(self.Nodes[0], self.Nodes[2])
             self.Transient_Voltage = voltage
-            
-            if (self.context.integration_method == "trapezoidal"):
-                self.Transient_Resistance = self.context.time_step / (2 * self.Output_Capacitance)
-                self.Transient_Current = (self.Transient_Voltage / self.Transient_Resistance + self.Equivalent_Current)
-                self.Equivalent_Current = (-self.Transient_Voltage / self.Transient_Resistance - self.Transient_Current)
-            elif (self.context.integration_method == "backward_euler"):
-                self.Transient_Resistance = self.context.time_step / self.Output_Capacitance
-                self.Transient_Current = (self.Transient_Voltage / self.Transient_Resistance)
+
+            if self.context.integration_method == "trapezoidal":
+                self.Transient_Resistance = self.context.time_step / (
+                    2 * self.Output_Capacitance
+                )
+                self.Transient_Current = (
+                    self.Transient_Voltage / self.Transient_Resistance
+                    + self.Equivalent_Current
+                )
+                self.Equivalent_Current = (
+                    -self.Transient_Voltage / self.Transient_Resistance
+                    - self.Transient_Current
+                )
+            elif self.context.integration_method == "backward_euler":
+                self.Transient_Resistance = (
+                    self.context.time_step / self.Output_Capacitance
+                )
+                self.Transient_Current = (
+                    self.Transient_Voltage / self.Transient_Resistance
+                )
                 self.Equivalent_Current = -self.Transient_Current
             else:
-                self.Transient_Resistance = self.context.time_step / (2 * self.Output_Capacitance)
-                self.Transient_Current = (self.Transient_Voltage / self.Transient_Resistance + self.Equivalent_Current)
-                self.Equivalent_Current = (-self.Transient_Voltage / self.Transient_Resistance - self.Transient_Current)
+                self.Transient_Resistance = self.context.time_step / (
+                    2 * self.Output_Capacitance
+                )
+                self.Transient_Current = (
+                    self.Transient_Voltage / self.Transient_Resistance
+                    + self.Equivalent_Current
+                )
+                self.Equivalent_Current = (
+                    -self.Transient_Voltage / self.Transient_Resistance
+                    - self.Transient_Current
+                )
 
     def conserve_energy(self) -> None:
         None
-        if (self.context.integration_method == "trapezoidal"):
-            self.Transient_Resistance = self.context.time_step / (2 * self.Output_Capacitance)
-            self.Equivalent_Current = (-self.Transient_Voltage / self.Transient_Resistance - self.Transient_Current)
-        elif (self.context.integration_method == "backward_euler"):
+        if self.context.integration_method == "trapezoidal":
+            self.Transient_Resistance = self.context.time_step / (
+                2 * self.Output_Capacitance
+            )
+            self.Equivalent_Current = (
+                -self.Transient_Voltage / self.Transient_Resistance
+                - self.Transient_Current
+            )
+        elif self.context.integration_method == "backward_euler":
             self.Transient_Resistance = self.context.time_step / self.Output_Capacitance
-            self.Equivalent_Current = (-self.Transient_Voltage / self.Transient_Resistance)
+            self.Equivalent_Current = (
+                -self.Transient_Voltage / self.Transient_Resistance
+            )
         else:
-            self.Transient_Resistance = self.context.time_step / (2 * self.Output_Capacitance)
-            self.Equivalent_Current = (-self.Transient_Voltage / self.Transient_Resistance - self.Transient_Current)
+            self.Transient_Resistance = self.context.time_step / (
+                2 * self.Output_Capacitance
+            )
+            self.Equivalent_Current = (
+                -self.Transient_Voltage / self.Transient_Resistance
+                - self.Transient_Current
+            )
 
     def GetElementType(self) -> int:
         None
