@@ -8,21 +8,21 @@ from mnapy import ZenerDiodeLimits
 
 class ZenerDiode:
     def __init__(
-            self,
-            context,
-            Last_Voltage,
-            Last_Current,
-            Zener_Voltage,
-            Saturation_Current,
-            Emission_Coefficient,
-            units,
-            options_units,
-            option_limits,
-            Resistance,
-            Voltage,
-            options,
-            tag,
-            Equivalent_Current,
+        self,
+        context,
+        Last_Voltage,
+        Last_Current,
+        Zener_Voltage,
+        Saturation_Current,
+        Emission_Coefficient,
+        units,
+        options_units,
+        option_limits,
+        Resistance,
+        Voltage,
+        options,
+        tag,
+        Equivalent_Current,
     ):
         self.Last_Voltage = Last_Voltage
         self.Last_Current = Last_Current
@@ -57,12 +57,12 @@ class ZenerDiode:
     def Set_Zener_Voltage(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Zener_Voltage[0])
-                and abs(setter) <= abs(self.option_limits.Zener_Voltage[1])
+            abs(setter) >= abs(self.option_limits.Zener_Voltage[0])
+            and abs(setter) <= abs(self.option_limits.Zener_Voltage[1])
         ) or abs(setter) == 0:
             self.Zener_Voltage = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Zener_Voltage(self) -> float:
         None
@@ -71,12 +71,12 @@ class ZenerDiode:
     def Set_Saturation_Current(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Saturation_Current[0])
-                and abs(setter) <= abs(self.option_limits.Saturation_Current[1])
+            abs(setter) >= abs(self.option_limits.Saturation_Current[0])
+            and abs(setter) <= abs(self.option_limits.Saturation_Current[1])
         ) or abs(setter) == 0:
             self.Saturation_Current = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Saturation_Current(self) -> float:
         None
@@ -85,12 +85,12 @@ class ZenerDiode:
     def Set_Emission_Coefficient(self, setter: float) -> None:
         None
         if (
-                setter > self.option_limits.Emission_Coefficient[0]
-                and setter < self.option_limits.Emission_Coefficient[1]
+            setter > self.option_limits.Emission_Coefficient[0]
+            and setter < self.option_limits.Emission_Coefficient[1]
         ):
             self.Emission_Coefficient = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Emission_Coefficient(self) -> float:
         None
@@ -109,7 +109,10 @@ class ZenerDiode:
 
     def update(self) -> None:
         None
-        if self.context.Params.SystemFlags.FlagSimulating and self.context.solutions_ready:
+        if (
+            self.context.Params.SystemFlags.FlagSimulating
+            and self.context.solutions_ready
+        ):
             self.Last_Voltage = self.Voltage
             self.Last_Current = self.Equivalent_Current
             next_voltage: float = self.context.get_voltage(self.Nodes[0], self.Nodes[1])
@@ -130,79 +133,83 @@ class ZenerDiode:
 
             diode_voltage = Utils.Utils.limit(diode_voltage, -self.Zener_Voltage, vcrit)
             self.gmin = Utils.Utils.gmin_step(
-                self.gmin_start, self.get_zener_error(), self.context.iterator, self.context
+                self.gmin_start,
+                self.get_zener_error(),
+                self.context.iterator,
+                self.context,
             )
             self.Voltage = diode_voltage
             adjusted_zener_voltage: float = (
-                    self.damping_safety_factor * self.Zener_Voltage
-                    - self.ZENER_MARGIN_SAFETY_FACTOR
+                self.damping_safety_factor * self.Zener_Voltage
+                - self.ZENER_MARGIN_SAFETY_FACTOR
             )
             if diode_voltage >= 0:
                 self.Resistance = 1.0 / (
-                        (
-                                self.Saturation_Current
-                                / (
-                                        self.Emission_Coefficient
-                                        * self.context.Params.SystemSettings.THERMAL_VOLTAGE
-                                )
-                        )
-                        * math.exp(
-                    self.Voltage
-                    / (
+                    (
+                        self.Saturation_Current
+                        / (
                             self.Emission_Coefficient
                             * self.context.Params.SystemSettings.THERMAL_VOLTAGE
+                        )
+                    )
+                    * math.exp(
+                        self.Voltage
+                        / (
+                            self.Emission_Coefficient
+                            * self.context.Params.SystemSettings.THERMAL_VOLTAGE
+                        )
                     )
                 )
-                )
                 self.Equivalent_Current = -(
-                        self.Saturation_Current
-                        * (
-                                math.exp(
-                                    self.Voltage
-                                    / (
-                                            self.Emission_Coefficient
-                                            * self.context.Params.SystemSettings.THERMAL_VOLTAGE
-                                    )
-                                )
-                                - 1
+                    self.Saturation_Current
+                    * (
+                        math.exp(
+                            self.Voltage
+                            / (
+                                self.Emission_Coefficient
+                                * self.context.Params.SystemSettings.THERMAL_VOLTAGE
+                            )
                         )
-                        - self.Voltage / self.Resistance
+                        - 1
+                    )
+                    - self.Voltage / self.Resistance
                 )
             else:
                 self.Resistance = 1.0 / (
-                        (
-                                self.Saturation_Current
-                                / (
-                                        self.Emission_Coefficient
-                                        * self.context.Params.SystemSettings.THERMAL_VOLTAGE
-                                )
-                        )
-                        * math.exp(
-                    (-self.Voltage - adjusted_zener_voltage)
-                    * (
-                            1.0
-                            / (
-                                    self.Emission_Coefficient
-                                    * self.context.Params.SystemSettings.THERMAL_VOLTAGE
-                            )
-                    )
-                )
-                )
-                self.Equivalent_Current = -(
+                    (
                         self.Saturation_Current
-                        * -math.exp(
-                    (-self.Voltage - adjusted_zener_voltage)
-                    / (
+                        / (
                             self.Emission_Coefficient
                             * self.context.Params.SystemSettings.THERMAL_VOLTAGE
+                        )
+                    )
+                    * math.exp(
+                        (-self.Voltage - adjusted_zener_voltage)
+                        * (
+                            1.0
+                            / (
+                                self.Emission_Coefficient
+                                * self.context.Params.SystemSettings.THERMAL_VOLTAGE
+                            )
+                        )
                     )
                 )
-                        - self.Voltage / self.Resistance
+                self.Equivalent_Current = -(
+                    self.Saturation_Current
+                    * -math.exp(
+                        (-self.Voltage - adjusted_zener_voltage)
+                        / (
+                            self.Emission_Coefficient
+                            * self.context.Params.SystemSettings.THERMAL_VOLTAGE
+                        )
+                    )
+                    - self.Voltage / self.Resistance
                 )
 
     def stamp(self) -> None:
         None
-        self.context.stamp_resistor(self.Nodes[0], self.Nodes[1], 1.0 / self.gmin)
+        if self.context.iterator >= self.gmin_start:
+            self.context.stamp_resistor(self.Nodes[0], self.Nodes[1], 1.0 / self.gmin)
         self.context.stamp_current(
             self.Nodes[0], self.Nodes[1], self.Equivalent_Current
         )
